.. include:: ../BADGES.rst

.. _tsgettoolbox_documentation:

tsgettoolbox
============

This is the home page for tsgettoolbox.  tsgettoolbox is a small Python library
for downloading and reformatting time-series data from various internet
sources.

tsgettoolbox will work with Python 3.6+.

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   readme
   notebooks
   command_line
   function_summary
   examples
   contributing
   authors
   license

Other Projects
--------------
http://timcera.bitbucket.io
